@@ -2,8 +2,10 @@
 
 __author__ = """Ralph Brecheisen"""
 __email__ = 'ralph.brecheisen@gmail.com'
-__version__ = '0.10.0'
+__version__ = '0.11.0'
 
+from .createh5.createh5 import CreateH5
 from .train.train import TrainL3
+from .genid.genid import GenID
 from . import models
 from . import utils
